Python: module undo

undo | index /tmp/makerelease-pwman-python.6KILBD5b/pwman-python-2.6/libpwman/undo.py

`# Simple password manager
# Copyright (c) 2011-2019 Michael Buesch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.`

Classes
`` |  | builtins.object UndoStack
class UndoStack(builtins.object)
`` | `UndoStack(limit=32768)`
| Methods defined here: __init__(self, limit=32768) `Initialize self. See help(type(self)) for accurate signature.` clear(self) do(self, doCommands, undoCommands) freeze(self) redo(self) thaw(self) undo(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Data
`` |  | __all__ = ['UndoStack']